@@ -63,6 +63,7 @@
 typedef struct
 {
 	GHashTable *cpt_table;
+	GHashTable *known_cids;
 	gchar *screenshot_service_url;
 	gchar *locale;
 	gchar *current_arch;
@@ -73,7 +74,10 @@ typedef struct
 
 	gchar **term_greylist;
 
+	AsPoolFlags flags;
 	AsCacheFlags cache_flags;
+	gboolean prefer_local_metainfo;
+
 	gchar *sys_cache_path;
 	gchar *user_cache_path;
 	time_t cache_ctime;
@@ -100,6 +104,12 @@ const gchar *AS_APPSTREAM_METADATA_PATHS[4] = { "/usr/share/app-info",
  */
 #define AS_SEARCH_GREYLIST_STR _("app;application;package;program;programme;suite;tool")
 
+/* where .desktop files are installed to by packages to be registered with the system */
+static gchar *APPLICATIONS_DIR = "/usr/share/applications";
+
+/* where metainfo files can be found */
+static gchar *METAINFO_DIR = "/usr/share/metainfo";
+
 static void as_pool_add_metadata_location_internal (AsPool *pool, const gchar *directory, gboolean add_root);
 
 /**
@@ -137,10 +147,18 @@ as_pool_init (AsPool *pool)
 	/* set active locale */
 	priv->locale = as_get_current_locale ();
 
+	/* stores known components */
 	priv->cpt_table = g_hash_table_new_full (g_str_hash,
 						g_str_equal,
 						g_free,
 						(GDestroyNotify) g_object_unref);
+
+	/* set which stores whether we have seen a component-ID already */
+	priv->known_cids = g_hash_table_new_full (g_str_hash,
+						  g_str_equal,
+						  g_free,
+						  NULL);
+
 	priv->xml_dirs = g_ptr_array_new_with_free_func (g_free);
 	priv->yaml_dirs = g_ptr_array_new_with_free_func (g_free);
 	priv->icon_dirs = g_ptr_array_new_with_free_func (g_free);
@@ -164,10 +182,22 @@ as_pool_init (AsPool *pool)
 	distro = as_distro_details_new ();
 	priv->screenshot_service_url = as_distro_details_get_str (distro, "ScreenshotUrl");
 
+	/* check whether we might want to prefer local metainfo files over remote data */
+	priv->prefer_local_metainfo = as_distro_details_get_bool (distro, "PreferLocalMetainfoData", FALSE);
+
 	/* set watched default directories for AppStream metadata */
 	for (i = 0; AS_APPSTREAM_METADATA_PATHS[i] != NULL; i++)
 		as_pool_add_metadata_location_internal (pool, AS_APPSTREAM_METADATA_PATHS[i], FALSE);
 
+	/* set default pool flags */
+	priv->flags = AS_POOL_FLAG_READ_COLLECTION |
+			AS_POOL_FLAG_READ_DESKTOP_FILES;
+	if (priv->prefer_local_metainfo) {
+		/* FIXME: We don't enable AS_POOL_FLAG_READ_METAINFO by default yet, because this feature is unfinished and needs work,
+		* mainly in the area of merging data together. */
+		priv->flags |= AS_POOL_FLAG_READ_METAINFO;
+	}
+
 	/* set default cache flags */
 	priv->cache_flags = AS_CACHE_FLAG_USE_SYSTEM | AS_CACHE_FLAG_USE_USER;
 }
@@ -183,6 +213,7 @@ as_pool_finalize (GObject *object)
 
 	g_free (priv->screenshot_service_url);
 	g_hash_table_unref (priv->cpt_table);
+	g_hash_table_unref (priv->known_cids);
 
 	g_ptr_array_unref (priv->xml_dirs);
 	g_ptr_array_unref (priv->yaml_dirs);
@@ -210,101 +241,58 @@ as_pool_class_init (AsPoolClass *klass)
 }
 
 /**
- * as_merge_components:
- *
- * Merge selected data from two components.
- */
-static void
-as_merge_components (AsComponent *dest_cpt, AsComponent *src_cpt)
-{
-	guint i;
-	AsMergeKind merge_kind;
-
-	merge_kind = as_component_get_merge_kind (src_cpt);
-	g_return_if_fail (merge_kind != AS_MERGE_KIND_NONE);
-
-	/* FIXME: We need to merge more attributes */
-
-	/* merge stuff in append mode */
-	if (merge_kind == AS_MERGE_KIND_APPEND) {
-		GPtrArray *suggestions;
-		GPtrArray *cats;
-
-		/* merge categories */
-		cats = as_component_get_categories (src_cpt);
-		if (cats->len > 0) {
-			g_autoptr(GHashTable) cat_table = NULL;
-			GPtrArray *dest_categories;
-
-			cat_table = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, NULL);
-			for (i = 0; i < cats->len; i++) {
-				const gchar *cat = (const gchar*) g_ptr_array_index (cats, i);
-				g_hash_table_add (cat_table, g_strdup (cat));
-			}
-
-			dest_categories = as_component_get_categories (dest_cpt);
-			if (dest_categories->len > 0) {
-				for (i = 0; i < dest_categories->len; i++) {
-					const gchar *cat = (const gchar*) g_ptr_array_index (dest_categories, i);
-					g_hash_table_add (cat_table, g_strdup (cat));
-				}
-			}
-
-			g_ptr_array_set_size (dest_categories, 0);
-			as_hash_table_string_keys_to_array (cat_table, dest_categories);
-		}
-
-		/* merge suggestions */
-		suggestions = as_component_get_suggested (src_cpt);
-		if (suggestions != NULL) {
-			for (i = 0; i < suggestions->len; i++) {
-				as_component_add_suggested (dest_cpt,
-						    AS_SUGGESTED (g_ptr_array_index (suggestions, i)));
-			}
-		}
-	}
-
-	/* merge stuff in replace mode */
-	if (merge_kind == AS_MERGE_KIND_REPLACE) {
-		gchar **pkgnames;
-
-		/* merge names */
-		if (as_component_get_name (src_cpt) != NULL)
-			as_component_set_name (dest_cpt, as_component_get_name (src_cpt), as_component_get_active_locale (src_cpt));
-
-		/* merge package names */
-		pkgnames = as_component_get_pkgnames (src_cpt);
-		if ((pkgnames != NULL) && (pkgnames[0] != '\0'))
-			as_component_set_pkgnames (dest_cpt, as_component_get_pkgnames (src_cpt));
-
-		/* merge bundles */
-		if (as_component_has_bundle (src_cpt))
-			as_component_set_bundles_array (dest_cpt, as_component_get_bundles (src_cpt));
-	}
-
-	g_debug ("Merged data for '%s'", as_component_get_data_id (dest_cpt));
-}
-
-/**
- * as_pool_add_component:
+ * as_pool_add_component_internal:
  * @pool: An instance of #AsPool
  * @cpt: The #AsComponent to add to the pool.
+ * @pedantic_noadd: If %TRUE, always emit an error if component couldn't be added.
  * @error: A #GError or %NULL
  *
- * Register a new component in the AppStream metadata pool.
- *
- * Returns: %TRUE if the new component was successfully added to the pool.
+ * Internal.
  */
-gboolean
-as_pool_add_component (AsPool *pool, AsComponent *cpt, GError **error)
+static gboolean
+as_pool_add_component_internal (AsPool *pool, AsComponent *cpt, gboolean pedantic_noadd, GError **error)
 {
 	const gchar *cdid = NULL;
 	AsComponent *existing_cpt;
 	gint pool_priority;
+	AsOriginKind new_cpt_orig_kind;
+	AsOriginKind existing_cpt_orig_kind;
 	AsPoolPrivate *priv = GET_PRIVATE (pool);
 
 	cdid = as_component_get_data_id (cpt);
+	if (as_component_is_ignored (cpt)) {
+		if (pedantic_noadd)
+			g_set_error (error,
+					AS_POOL_ERROR,
+					AS_POOL_ERROR_FAILED,
+					"Skipping '%s' from inclusion into the pool: Component is ignored.", cdid);
+		return FALSE;
+	}
+
+	new_cpt_orig_kind = as_component_get_origin_kind (cpt);
+
 	existing_cpt = g_hash_table_lookup (priv->cpt_table, cdid);
+	if (as_component_get_origin_kind (cpt) == AS_ORIGIN_KIND_DESKTOP_ENTRY) {
+		g_autofree gchar *tmp_cdid = NULL;
+
+		/* .desktop entries might map to existing metadata data with or without .desktop suffix, we need to check for that.
+		 * (the .desktop suffix is optional for desktop-application metainfo files, and the desktop-entry parser will automatically
+		 * omit it if the desktop-entry-id is following the reverse DNS scheme)
+		 */
+		if (existing_cpt == NULL) {
+			tmp_cdid = g_strdup_printf ("%s.desktop", cdid);
+			existing_cpt = g_hash_table_lookup (priv->cpt_table, tmp_cdid);
+		}
+
+		if (existing_cpt != NULL) {
+			if (as_component_get_origin_kind (cpt) != AS_ORIGIN_KIND_DESKTOP_ENTRY) {
+				/* discard tthis component if we have anything better data already in the pool,
+				 * which is basically anything *but* data from a .desktop file */
+				g_debug ("Ignored .desktop metadata for '%s': Better data exists.", cdid);
+				return FALSE;
+			}
+		}
+	}
 
 	if (existing_cpt == NULL) {
 		/* add additional data to the component, e.g. external screenshots. Also refines
@@ -316,6 +304,55 @@ as_pool_add_component (AsPool *pool, AsComponent *cpt, GError **error)
 		g_hash_table_insert (priv->cpt_table,
 					g_strdup (cdid),
 					g_object_ref (cpt));
+		g_hash_table_add (priv->known_cids,
+				  g_strdup (as_component_get_id (cpt)));
+		return TRUE;
+	}
+
+	existing_cpt_orig_kind = as_component_get_origin_kind (existing_cpt);
+
+	/* always replace data from .desktop entries */
+	if (existing_cpt_orig_kind == AS_ORIGIN_KIND_DESKTOP_ENTRY) {
+		if (new_cpt_orig_kind == AS_ORIGIN_KIND_METAINFO) {
+			/* do an append-merge to ensure the data from an exusting metainfo file has an icon */
+			as_component_merge_with_mode (cpt,
+							existing_cpt,
+							AS_MERGE_KIND_APPEND);
+
+			g_hash_table_replace (priv->cpt_table,
+				g_strdup (cdid),
+				g_object_ref (cpt));
+			g_debug ("Replaced '%s' with data from metainfo and desktop-entry file.", cdid);
+			return TRUE;
+		} else {
+			as_component_set_priority (existing_cpt, -G_MAXINT);
+		}
+	}
+
+	/* merge desktop-entry data in, if we already have existing data from a metainfo file */
+	if (new_cpt_orig_kind == AS_ORIGIN_KIND_DESKTOP_ENTRY) {
+		if (existing_cpt_orig_kind == AS_ORIGIN_KIND_METAINFO) {
+			/* do an append-merge to ensure the metainfo file has an icon */
+			as_component_merge_with_mode (existing_cpt,
+						      cpt,
+						      AS_MERGE_KIND_APPEND);
+			g_debug ("Merged desktop-entry data into metainfo data for '%s'.", cdid);
+			return TRUE;
+		}
+	}
+
+	/* check whether we should prefer data from metainfo files over preexisting data */
+	if ((priv->prefer_local_metainfo) &&
+	    (new_cpt_orig_kind == AS_ORIGIN_KIND_METAINFO)) {
+		/* update package info, metainfo files do never have this data.
+		 * (we hope that collection data was loaded first here, so the existing_cpt already contains
+		 *  the information we want - if that's not the case, no harm is done here) */
+		as_component_set_pkgnames (cpt, as_component_get_pkgnames (existing_cpt));
+
+		g_hash_table_replace (priv->cpt_table,
+				g_strdup (cdid),
+				g_object_ref (cpt));
+		g_debug ("Replaced '%s' with data from metainfo file.", cdid);
 		return TRUE;
 	}
 
@@ -329,7 +366,7 @@ as_pool_add_component (AsPool *pool, AsComponent *cpt, GError **error)
 							as_component_get_id (cpt));
 		for (i = 0; i < matches->len; i++) {
 			AsComponent *match = AS_COMPONENT (g_ptr_array_index (matches, i));
-			as_merge_components (match, cpt);
+			as_component_merge (match, cpt);
 		}
 
 		return TRUE;
@@ -382,10 +419,11 @@ as_pool_add_component (AsPool *pool, AsComponent *cpt, GError **error)
 					"Detected colliding ids: %s was already added with the same priority.", cdid);
 			return FALSE;
 		} else {
-			g_set_error (error,
-					AS_POOL_ERROR,
-					AS_POOL_ERROR_COLLISION,
-					"Detected colliding ids: %s was already added with a higher priority.", cdid);
+			if (pedantic_noadd)
+				g_set_error (error,
+						AS_POOL_ERROR,
+						AS_POOL_ERROR_COLLISION,
+						"Detected colliding ids: %s was already added with a higher priority.", cdid);
 			return FALSE;
 		}
 	}
@@ -393,6 +431,22 @@ as_pool_add_component (AsPool *pool, AsComponent *cpt, GError **error)
 	return TRUE;
 }
 
+/**
+ * as_pool_add_component:
+ * @pool: An instance of #AsPool
+ * @cpt: The #AsComponent to add to the pool.
+ * @error: A #GError or %NULL
+ *
+ * Register a new component in the AppStream metadata pool.
+ *
+ * Returns: %TRUE if the new component was successfully added to the pool.
+ */
+gboolean
+as_pool_add_component (AsPool *pool, AsComponent *cpt, GError **error)
+{
+	return as_pool_add_component_internal (pool, cpt, TRUE, error);
+}
+
 /**
  * as_pool_update_addon_info:
  *
@@ -415,7 +469,7 @@ as_pool_update_addon_info (AsPool *pool, AsComponent *cpt)
 		g_autofree gchar *extended_cdid = NULL;
 		const gchar *extended_cid = (const gchar*) g_ptr_array_index (extends, i);
 
-		extended_cdid = as_utils_build_data_id ("system", "os",
+		extended_cdid = as_utils_build_data_id (AS_COMPONENT_SCOPE_SYSTEM, "os",
 							as_utils_get_component_bundle_kind (cpt),
 							extended_cid);
 
@@ -464,8 +518,15 @@ as_pool_refine_data (AsPool *pool)
 
 		/* validate the component */
 		if (!as_component_is_valid (cpt)) {
-			g_debug ("WARNING: Skipped component '%s': The component is invalid.", as_component_get_id (cpt));
-			ret = FALSE;
+			/* we still succeed if the components originates from a .desktop file -
+			 * we care less about them and they generally have bad quality, so some issues
+			 * pop up on pretty much every system */
+			if (as_component_get_origin_kind (cpt) == AS_ORIGIN_KIND_DESKTOP_ENTRY) {
+				g_debug ("Ignored '%s': The component (from a .desktop file) is invalid.", as_component_get_id (cpt));
+			} else {
+				g_debug ("WARNING: Ignored component '%s': The component is invalid.", as_component_get_id (cpt));
+				ret = FALSE;
+			}
 			continue;
 		}
 
@@ -486,12 +547,82 @@ as_pool_refine_data (AsPool *pool)
 }
 
 /**
- * as_pool_load_metadata:
+ * as_pool_clear:
+ * @pool: An #AsPool.
  *
- * Load fresh metadata from AppStream directories.
+ * Remove all metadat from the pool.
+ */
+void
+as_pool_clear (AsPool *pool)
+{
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
+	if (g_hash_table_size (priv->cpt_table) > 0) {
+		/* contents */
+		g_hash_table_unref (priv->cpt_table);
+		priv->cpt_table = g_hash_table_new_full (g_str_hash,
+							 g_str_equal,
+							 g_free,
+							 (GDestroyNotify) g_object_unref);
+
+		/* cid info set */
+		g_hash_table_unref (priv->known_cids);
+		priv->known_cids = g_hash_table_new_full (g_str_hash,
+						  g_str_equal,
+						  g_free,
+						  NULL);
+	}
+}
+
+/**
+ * as_pool_ctime_newer:
+ *
+ * Returns: %TRUE if ctime of file is newer than the cached time.
  */
 static gboolean
-as_pool_load_metadata (AsPool *pool)
+as_pool_ctime_newer (AsPool *pool, const gchar *dir)
+{
+	struct stat sb;
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
+
+	if (stat (dir, &sb) < 0)
+		return FALSE;
+
+	if (sb.st_ctime > priv->cache_ctime)
+		return TRUE;
+
+	return FALSE;
+}
+
+/**
+ * as_pool_appstream_data_changed:
+ */
+static gboolean
+as_pool_metadata_changed (AsPool *pool)
+{
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
+	guint i;
+
+	for (i = 0; i < priv->xml_dirs->len; i++) {
+		const gchar *dir = (const gchar*) g_ptr_array_index (priv->xml_dirs, i);
+		if (as_pool_ctime_newer (pool, dir))
+			return TRUE;
+	}
+	for (i = 0; i < priv->yaml_dirs->len; i++) {
+		const gchar *dir = (const gchar*) g_ptr_array_index (priv->yaml_dirs, i);
+		if (as_pool_ctime_newer (pool, dir))
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
+/**
+ * as_pool_load_collection_data:
+ *
+ * Load fresh metadata from AppStream collection data directories.
+ */
+static gboolean
+as_pool_load_collection_data (AsPool *pool, GError **error)
 {
 	GPtrArray *cpts;
 	g_autoptr(GPtrArray) merge_cpts = NULL;
@@ -499,9 +630,28 @@ as_pool_load_metadata (AsPool *pool)
 	gboolean ret;
 	g_autoptr(AsMetadata) metad = NULL;
 	g_autoptr(GPtrArray) mdata_files = NULL;
-	GError *error = NULL;
+	GError *tmp_error = NULL;
 	AsPoolPrivate *priv = GET_PRIVATE (pool);
 
+	/* see if we can use the caches */
+	if (!as_pool_metadata_changed (pool)) {
+		g_autofree gchar *fname = NULL;
+		g_debug ("Caches are up to date.");
+
+		if (as_flags_contains (priv->cache_flags, AS_CACHE_FLAG_USE_SYSTEM)) {
+			g_debug ("Using cached data.");
+
+			fname = g_strdup_printf ("%s/%s.gvz", priv->sys_cache_path, priv->locale);
+			if (g_file_test (fname, G_FILE_TEST_EXISTS)) {
+				return as_pool_load_cache_file (pool, fname, error);
+			} else {
+				g_debug ("Missing cache for language '%s', attempting to load fresh data.", priv->locale);
+			}
+		} else {
+			g_debug ("Not using system cache.");
+		}
+	}
+
 	/* prepare metadata parser */
 	metad = as_metadata_new ();
 	as_metadata_set_format_style (metad, AS_FORMAT_STYLE_COLLECTION);
@@ -570,32 +720,49 @@ as_pool_load_metadata (AsPool *pool)
 		as_metadata_parse_file (metad,
 					infile,
 					AS_FORMAT_KIND_UNKNOWN,
-					&error);
-		if (error != NULL) {
-			g_debug ("WARNING: %s", error->message);
-			g_error_free (error);
-			error = NULL;
+					&tmp_error);
+		if (tmp_error != NULL) {
+			g_debug ("WARNING: %s", tmp_error->message);
+			g_error_free (tmp_error);
+			tmp_error = NULL;
 			ret = FALSE;
+
+			if (error != NULL) {
+				if (*error == NULL)
+					g_set_error_literal (error,
+							     AS_POOL_ERROR,
+							     AS_POOL_ERROR_FAILED,
+							     fname);
+				else
+					g_prefix_error (error, "%s, ", fname);
+			}
 		}
 	}
 
+	/* finalize error message, if we had errors */
+	if ((error != NULL) && (*error != NULL))
+		g_prefix_error (error, "%s ", _("Metadata files have errors:"));
+
 	/* add found components to the metadata pool */
 	cpts = as_metadata_get_components (metad);
 	merge_cpts = g_ptr_array_new ();
 	for (i = 0; i < cpts->len; i++) {
 		AsComponent *cpt = AS_COMPONENT (g_ptr_array_index (cpts, i));
 
+		/* TODO: We support only system components at time */
+		as_component_set_scope (cpt, AS_COMPONENT_SCOPE_SYSTEM);
+
 		/* deal with merge-components later */
 		if (as_component_get_merge_kind (cpt) != AS_MERGE_KIND_NONE) {
 			g_ptr_array_add (merge_cpts, cpt);
 			continue;
 		}
 
-		as_pool_add_component (pool, cpt, &error);
-		if (error != NULL) {
-			g_debug ("Metadata ignored: %s", error->message);
-			g_error_free (error);
-			error = NULL;
+		as_pool_add_component (pool, cpt, &tmp_error);
+		if (tmp_error != NULL) {
+			g_debug ("Metadata ignored: %s", tmp_error->message);
+			g_error_free (tmp_error);
+			tmp_error = NULL;
 		}
 	}
 
@@ -604,11 +771,11 @@ as_pool_load_metadata (AsPool *pool)
 	for (i = 0; i < merge_cpts->len; i++) {
 		AsComponent *mcpt = AS_COMPONENT (g_ptr_array_index (merge_cpts, i));
 
-		as_pool_add_component (pool, mcpt, &error);
-		if (error != NULL) {
-			g_debug ("Merge component ignored: %s", error->message);
-			g_error_free (error);
-			error = NULL;
+		as_pool_add_component (pool, mcpt, &tmp_error);
+		if (tmp_error != NULL) {
+			g_debug ("Merge component ignored: %s", tmp_error->message);
+			g_error_free (tmp_error);
+			tmp_error = NULL;
 		}
 	}
 
@@ -616,65 +783,183 @@ as_pool_load_metadata (AsPool *pool)
 }
 
 /**
- * as_pool_clear:
- * @pool: An #AsPool.
+ * as_pool_load_metainfo_data:
  *
- * Remove all metadat from the pool.
+ * Load fresh metadata from metainfo files.
  */
-void
-as_pool_clear (AsPool *pool)
+static void
+as_pool_load_metainfo_data (AsPool *pool)
 {
-	AsPoolPrivate *priv = GET_PRIVATE (pool);
-	if (g_hash_table_size (priv->cpt_table) > 0) {
-		g_hash_table_unref (priv->cpt_table);
-		priv->cpt_table = g_hash_table_new_full (g_str_hash,
-							 g_str_equal,
-							 g_free,
-							 (GDestroyNotify) g_object_unref);
-	}
-}
-
-/**
- * as_pool_ctime_newer:
- *
- * Returns: %TRUE if ctime of file is newer than the cached time.
- */
-static gboolean
-as_pool_ctime_newer (AsPool *pool, const gchar *dir)
-{
-	struct stat sb;
-	AsPoolPrivate *priv = GET_PRIVATE (pool);
-
-	if (stat (dir, &sb) < 0)
-		return FALSE;
-
-	if (sb.st_ctime > priv->cache_ctime)
-		return TRUE;
-
-	return FALSE;
-}
-
-/**
- * as_pool_appstream_data_changed:
- */
-static gboolean
-as_pool_metadata_changed (AsPool *pool)
-{
-	AsPoolPrivate *priv = GET_PRIVATE (pool);
 	guint i;
+	g_autoptr(AsMetadata) metad = NULL;
+	g_autoptr(GPtrArray) mi_files = NULL;
+	GPtrArray *cpts;
+	GError *error = NULL;
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
 
-	for (i = 0; i < priv->xml_dirs->len; i++) {
-		const gchar *dir = (const gchar*) g_ptr_array_index (priv->xml_dirs, i);
-		if (as_pool_ctime_newer (pool, dir))
-			return TRUE;
-	}
-	for (i = 0; i < priv->yaml_dirs->len; i++) {
-		const gchar *dir = (const gchar*) g_ptr_array_index (priv->yaml_dirs, i);
-		if (as_pool_ctime_newer (pool, dir))
-			return TRUE;
+	/* prepare metadata parser */
+	metad = as_metadata_new ();
+	as_metadata_set_locale (metad, priv->locale);
+
+	/* find metainfo files */
+	g_debug ("Searching for data in: %s", METAINFO_DIR);
+	mi_files = as_utils_find_files_matching (METAINFO_DIR, "*.xml", FALSE, NULL);
+	if (mi_files == NULL) {
+		g_debug ("Unable find metainfo files.");
+		return;
 	}
 
-	return FALSE;
+	/* parse the found data */
+	for (i = 0; i < mi_files->len; i++) {
+		g_autoptr(GFile) infile = NULL;
+		const gchar *fname = (const gchar*) g_ptr_array_index (mi_files, i);
+
+		if (!priv->prefer_local_metainfo) {
+			g_autofree gchar *mi_cid = NULL;
+
+			mi_cid = g_path_get_basename (fname);
+			if (g_str_has_suffix (mi_cid, ".metainfo.xml"))
+				mi_cid[strlen (mi_cid) - 13] = '\0';
+			if (g_str_has_suffix (mi_cid, ".appdata.xml")) {
+				g_autofree gchar *mi_cid_desktop = NULL;
+				mi_cid[strlen (mi_cid) - 12] = '\0';
+
+				mi_cid_desktop = g_strdup_printf ("%s.desktop", mi_cid);
+				/* check with .desktop suffix too */
+				if (!g_hash_table_contains (priv->known_cids, mi_cid_desktop)) {
+					g_debug ("Skipped: %s (already known)", fname);
+					continue;
+				}
+			}
+
+			/* quickly check if we know the component already */
+			if (!g_hash_table_contains (priv->known_cids, mi_cid)) {
+				g_debug ("Skipped: %s (already known)", fname);
+				continue;
+			}
+		}
+
+		g_debug ("Reading: %s", fname);
+		infile = g_file_new_for_path (fname);
+		if (!g_file_query_exists (infile, NULL)) {
+			g_warning ("Metadata file '%s' does not exist.", fname);
+			continue;
+		}
+
+		as_metadata_parse_file (metad,
+					infile,
+					AS_FORMAT_KIND_UNKNOWN,
+					&error);
+		if (error != NULL) {
+			g_debug ("WARNING: %s", error->message);
+			g_error_free (error);
+			error = NULL;
+		}
+	}
+
+	/* add found components to the metadata pool */
+	cpts = as_metadata_get_components (metad);
+	for (i = 0; i < cpts->len; i++) {
+		AsComponent *cpt = AS_COMPONENT (g_ptr_array_index (cpts, i));
+
+		/* We only read metainfo files from system directories */
+		as_component_set_scope (cpt, AS_COMPONENT_SCOPE_SYSTEM);
+
+		as_pool_add_component_internal (pool, cpt, FALSE, &error);
+		if (error != NULL) {
+			g_debug ("Metadata ignored: %s", error->message);
+			g_error_free (error);
+			error = NULL;
+		}
+	}
+}
+
+/**
+ * as_pool_load_desktop_entries:
+ *
+ * Load fresh metadata from .desktop files.
+ */
+static void
+as_pool_load_desktop_entries (AsPool *pool)
+{
+	guint i;
+	g_autoptr(AsMetadata) metad = NULL;
+	g_autoptr(GPtrArray) de_files = NULL;
+	GPtrArray *cpts;
+	GError *error = NULL;
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
+
+	/* prepare metadata parser */
+	metad = as_metadata_new ();
+	as_metadata_set_locale (metad, priv->locale);
+
+	/* find .desktop files */
+	g_debug ("Searching for data in: %s", APPLICATIONS_DIR);
+	de_files = as_utils_find_files_matching (APPLICATIONS_DIR, "*.desktop", FALSE, NULL);
+	if (de_files == NULL) {
+		g_debug ("Unable find .desktop files.");
+		return;
+	}
+
+	/* parse the found data */
+	for (i = 0; i < de_files->len; i++) {
+		g_autoptr(GFile) infile = NULL;
+		const gchar *fname = (const gchar*) g_ptr_array_index (de_files, i);
+
+		/* quickly check if we know the component already
+		 * We do not do this when reading metainfo files, since in that case we might
+		 * need to extend their data with .desktop file data. */
+		if (!as_flags_contains (priv->flags, AS_POOL_FLAG_READ_METAINFO)) {
+			g_autofree gchar *de_cid = g_path_get_basename (fname);
+
+			if (!g_hash_table_contains (priv->known_cids, de_cid)) {
+				g_debug ("Skipped: %s (already known)", fname);
+				continue;
+			}
+
+			/* check without .desktop suffix too */
+			if (g_str_has_suffix (de_cid, ".desktop")) {
+				de_cid[strlen (de_cid) - 8] = '\0';
+				if (!g_hash_table_contains (priv->known_cids, de_cid)) {
+					g_debug ("Skipped: %s (already known)", fname);
+					continue;
+				}
+			}
+		}
+
+		g_debug ("Reading: %s", fname);
+		infile = g_file_new_for_path (fname);
+		if (!g_file_query_exists (infile, NULL)) {
+			g_warning ("Metadata file '%s' does not exist.", fname);
+			continue;
+		}
+
+		as_metadata_parse_file (metad,
+					infile,
+					AS_FORMAT_KIND_UNKNOWN,
+					&error);
+		if (error != NULL) {
+			g_debug ("WARNING: %s", error->message);
+			g_error_free (error);
+			error = NULL;
+		}
+	}
+
+	/* add found components to the metadata pool */
+	cpts = as_metadata_get_components (metad);
+	for (i = 0; i < cpts->len; i++) {
+		AsComponent *cpt = AS_COMPONENT (g_ptr_array_index (cpts, i));
+
+		/* We only read .desktop files from system directories at time */
+		as_component_set_scope (cpt, AS_COMPONENT_SCOPE_SYSTEM);
+
+		as_pool_add_component_internal (pool, cpt, FALSE, &error);
+		if (error != NULL) {
+			g_debug ("Metadata ignored: %s", error->message);
+			g_error_free (error);
+			error = NULL;
+		}
+	}
 }
 
 /**
@@ -694,44 +979,28 @@ as_pool_metadata_changed (AsPool *pool)
 gboolean
 as_pool_load (AsPool *pool, GCancellable *cancellable, GError **error)
 {
-	gboolean ret;
-	gboolean ret2;
 	AsPoolPrivate *priv = GET_PRIVATE (pool);
+	gboolean ret = TRUE;
 
 	/* load means to reload, so we get rid of all the old data */
-	if (g_hash_table_size (priv->cpt_table) > 0) {
-		g_hash_table_unref (priv->cpt_table);
-		priv->cpt_table = g_hash_table_new_full (g_str_hash,
-							 g_str_equal,
-							 g_free,
-							 (GDestroyNotify) g_object_unref);
-	}
-
-	if (!as_pool_metadata_changed (pool)) {
-		g_autofree gchar *fname = NULL;
-		g_debug ("Caches are up to date.");
-
-		if (as_flags_contains (priv->cache_flags, AS_CACHE_FLAG_USE_SYSTEM)) {
-			g_debug ("Using cached data.");
-
-			fname = g_strdup_printf ("%s/%s.gvz", priv->sys_cache_path, priv->locale);
-			if (g_file_test (fname, G_FILE_TEST_EXISTS)) {
-				return as_pool_load_cache_file (pool, fname, error);
-			} else {
-				g_debug ("Missing cache for language '%s', attempting to load fresh data.", priv->locale);
-			}
-		} else {
-			g_debug ("Not using system cache.");
-		}
-	}
+	as_pool_clear (pool);
 
 	/* read all AppStream metadata that we can find */
-	ret = as_pool_load_metadata (pool);
+	if (as_flags_contains (priv->flags, AS_POOL_FLAG_READ_COLLECTION))
+		ret = as_pool_load_collection_data (pool, error);
+
+	/* read all metainfo files that we can find */
+	if (as_flags_contains (priv->flags, AS_POOL_FLAG_READ_METAINFO))
+		as_pool_load_metainfo_data (pool);
+
+	/* read all .desktop file data that we can find */
+	if (as_flags_contains (priv->flags, AS_POOL_FLAG_READ_DESKTOP_FILES))
+		as_pool_load_desktop_entries (pool);
 
 	/* automatically refine the metadata we have in the pool */
-	ret2 = as_pool_refine_data (pool);
+	ret = as_pool_refine_data (pool) && ret;
 
-	return ret && ret2;
+	return ret;
 }
 
 /**
@@ -760,6 +1029,9 @@ as_pool_load_cache_file (AsPool *pool, const gchar *fname, GError **error)
 	for (i = 0; i < cpts->len; i++) {
 		AsComponent *cpt = AS_COMPONENT (g_ptr_array_index (cpts, i));
 
+		/* TODO: Caches are system wide only at time, so we only have system-scope components in there */
+		as_component_set_scope (cpt, AS_COMPONENT_SCOPE_SYSTEM);
+
 		as_pool_add_component (pool, cpt, &tmp_error);
 		if (tmp_error != NULL) {
 			g_warning ("Cached data ignored: %s", tmp_error->message);
@@ -1045,7 +1317,8 @@ as_pool_build_search_terms (AsPool *pool, const gchar *search)
 /**
  * as_sort_components_by_score_cb:
  *
- * Helper method to sort result arrays by the #AsComponent match score.
+ * Helper method to sort result arrays by the #AsComponent match score
+ * with higher scores appearing higher in the list.
  */
 static gint
 as_sort_components_by_score_cb (gconstpointer a, gconstpointer b)
@@ -1056,9 +1329,9 @@ as_sort_components_by_score_cb (gconstpointer a, gconstpointer b)
 	s1 = as_component_get_sort_score (cpt1);
 	s2 = as_component_get_sort_score (cpt2);
 
-	if (s1 < s2)
-		return -1;
 	if (s1 > s2)
+		return -1;
+	if (s1 < s2)
 		return 1;
 	return 0;
 }
@@ -1069,7 +1342,7 @@ as_sort_components_by_score_cb (gconstpointer a, gconstpointer b)
  * @search: A search string
  *
  * Search for a list of components matching the search terms.
- * The list will be unordered.
+ * The list will be ordered by match score.
  *
  * Returns: (transfer container) (element-type AsComponent): an array of the found #AsComponent objects.
  *
@@ -1131,6 +1404,7 @@ as_pool_refresh_cache (AsPool *pool, gboolean force, GError **error)
 	gboolean ret = FALSE;
 	gboolean ret_poolupdate;
 	g_autofree gchar *cache_fname = NULL;
+	g_autoptr(GError) data_load_error = NULL;
 	g_autoptr(GError) tmp_error = NULL;
 
 	/* try to create cache directory, in case it doesn't exist */
@@ -1170,14 +1444,16 @@ as_pool_refresh_cache (AsPool *pool, gboolean force, GError **error)
 	}
 	g_debug ("Refreshing AppStream cache");
 
-	/* find them wherever they are */
-	ret_poolupdate = as_pool_load (pool, NULL, &tmp_error);
-	if (tmp_error != NULL) {
-		/* the exact error is not forwarded here, since we might be able to partially update the cache */
-		g_warning ("Error while updating the in-memory data pool: %s", tmp_error->message);
-		g_error_free (tmp_error);
-		tmp_error = NULL;
-	}
+	/* ensure we start with an empty pool */
+	as_pool_clear (pool);
+
+	/* NOTE: we will only cache AppStream metadata, no .desktop file metadata etc. */
+
+	/* load AppStream collection metadata only and refine it */
+	ret = as_pool_load_collection_data (pool, &data_load_error);
+	ret_poolupdate = as_pool_refine_data (pool) && ret;
+	if (data_load_error != NULL)
+		g_debug ("Error while updating the in-memory data pool: %s", data_load_error->message);
 
 	/* save the cache object */
 	as_pool_save_cache_file (pool, cache_fname, &tmp_error);
@@ -1193,10 +1469,16 @@ as_pool_refresh_cache (AsPool *pool, gboolean force, GError **error)
 
 	if (ret) {
 		if (!ret_poolupdate) {
-			g_set_error (error,
+			g_autofree gchar *error_message = NULL;
+			if (data_load_error == NULL)
+				error_message = g_strdup (_("The AppStream system cache was updated, but some errors were detected, which might lead to missing metadata. Refer to the verbose log for more information."));
+			else
+				error_message = g_strdup_printf (_("AppStream system cache was updated, but problems were found: %s"), data_load_error->message);
+
+			g_set_error_literal (error,
 				AS_POOL_ERROR,
 				AS_POOL_ERROR_INCOMPLETE,
-				_("AppStream data pool was loaded, but some metadata was ignored due to errors."));
+				error_message);
 		}
 		/* update the cache mtime, to not needlessly rebuild it again */
 		as_touch_location (cache_fname);
@@ -1205,7 +1487,7 @@ as_pool_refresh_cache (AsPool *pool, gboolean force, GError **error)
 		g_set_error (error,
 				AS_POOL_ERROR,
 				AS_POOL_ERROR_FAILED,
-				_("AppStream cache update failed."));
+				_("AppStream cache update failed. Turn on verbose mode to get more detailed issue information."));
 	}
 
 	return TRUE;
@@ -1363,6 +1645,33 @@ as_pool_set_cache_flags (AsPool *pool, AsCacheFlags flags)
 	priv->cache_flags = flags;
 }
 
+/**
+ * as_pool_get_flags:
+ * @pool: An instance of #AsPool.
+ *
+ * Get the #AsPoolFlags for this data pool.
+ */
+AsPoolFlags
+as_pool_get_flags (AsPool *pool)
+{
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
+	return priv->flags;
+}
+
+/**
+ * as_pool_set_flags:
+ * @pool: An instance of #AsPool.
+ * @flags: The new #AsPoolFlags.
+ *
+ * Set the #AsPoolFlags for this data pool.
+ */
+void
+as_pool_set_flags (AsPool *pool, AsPoolFlags flags)
+{
+	AsPoolPrivate *priv = GET_PRIVATE (pool);
+	priv->flags = flags;
+}
+
 /**
  * as_pool_get_cache_age:
  * @pool: An instance of #AsPool.
