@@ -41,6 +41,7 @@
 #include "as-resources.h"
 #include "as-category.h"
 #include "as-component.h"
+#include "as-component-private.h"
 
 /**
  * SECTION:as-utils
@@ -1054,14 +1055,14 @@ as_utils_compare_versions (const gchar* a, const gchar *b)
  * Builds the unique metadata ID using the supplied information.
  */
 gchar*
-as_utils_build_data_id (const gchar *scope,
+as_utils_build_data_id (AsComponentScope scope,
 			const gchar *origin,
 			AsBundleKind bundle_kind,
 			const gchar *cid)
 {
 	/* build the data-id */
 	return g_strdup_printf ("%s/%s/%s/%s",
-				scope,
+				as_component_scope_to_string (scope),
 				origin,
 				as_bundle_kind_to_string (bundle_kind),
 				cid);
@@ -1114,26 +1115,21 @@ as_utils_get_component_bundle_kind (AsComponent *cpt)
 gchar*
 as_utils_build_data_id_for_cpt (AsComponent *cpt)
 {
-	const gchar *scope;
 	const gchar *origin;
 	AsBundleKind bundle_kind;
 
-	/* FIXME: We don't really support scopes yet, will come in a future
-	 * release. */
-	scope = "system";
-
 	/* determine bundle - what should we do if there are multiple bundles of different types
 	 * defined for one component? */
 	bundle_kind = as_utils_get_component_bundle_kind (cpt);
 
-	/* FIXME: packages share one namespace, therefore we edit the origin here for now. */
+	/* NOTE: packages share one namespace, therefore we edit the origin here for now. */
 	if (bundle_kind == AS_BUNDLE_KIND_PACKAGE)
 		origin = "os";
 	else
 		origin = as_component_get_origin (cpt);
 
 	/* build the data-id */
-	return as_utils_build_data_id (scope,
+	return as_utils_build_data_id (as_component_get_scope (cpt),
 					origin,
 					bundle_kind,
 					as_component_get_id (cpt));
