@@ -758,7 +758,7 @@ as_component_set_kind_from_node (AsComponent *cpt, xmlNode *node)
 		ckind = as_component_kind_from_string (cpttype);
 		as_component_set_kind (cpt, ckind);
 		if (ckind == AS_COMPONENT_KIND_UNKNOWN)
-			g_debug ("An unknown component was found: %s", cpttype);
+			g_debug ("Found unknown component type: %s", cpttype);
 	}
 }
 
@@ -853,6 +853,33 @@ as_xml_icon_set_size_from_node (xmlNode *node, AsIcon *icon)
 	}
 }
 
+/**
+ * as_xml_process_custom_tag:
+ */
+static void
+as_xml_process_custom_tag (xmlNode *node, AsComponent *cpt)
+{
+	xmlNode *iter;
+	GHashTable *custom;
+
+	custom = as_component_get_custom (cpt);
+	for (iter = node->children; iter != NULL; iter = iter->next) {
+		gchar *key_str = NULL;
+
+		if (iter->type != XML_ELEMENT_NODE)
+			continue;
+		if (g_strcmp0 ((gchar*) iter->name, "value") != 0)
+			continue;
+
+		key_str = (gchar*) xmlGetProp (iter, (xmlChar*) "key");
+		if (key_str == NULL)
+			continue;
+		g_hash_table_insert (custom,
+				     key_str,
+				     as_xml_get_node_value (iter));
+	}
+}
+
 /**
  * as_xmldata_parse_component_node:
  */
@@ -1035,7 +1062,7 @@ as_xmldata_parse_component_node (AsXMLData *xdt, xmlNode* node, AsComponent *cpt
 
 				type_str = (gchar*) xmlGetProp (iter, (xmlChar*) "type");
 				bundle_kind = as_bundle_kind_from_string (type_str);
-				if (bundle_kind != AS_BUNDLE_KIND_UNKNOWN)
+				if (bundle_kind == AS_BUNDLE_KIND_UNKNOWN)
 					bundle_kind = AS_BUNDLE_KIND_LIMBA;
 				bundle = as_bundle_new ();
 				as_bundle_set_kind (bundle, bundle_kind);
@@ -1059,6 +1086,8 @@ as_xmldata_parse_component_node (AsXMLData *xdt, xmlNode* node, AsComponent *cpt
 			}
 		} else if (g_strcmp0 (node_name, "suggests") == 0) {
 			as_xml_process_suggests_tag (iter, cpt);
+		} else if (g_strcmp0 (node_name, "custom") == 0) {
+			as_xml_process_custom_tag (iter, cpt);
 		}
 	}
 
@@ -1614,6 +1643,11 @@ as_xml_serialize_provides (AsComponent *cpt, xmlNode *cnode)
 							"python3",
 							items);
 				break;
+			case AS_PROVIDED_KIND_FONT:
+				as_xml_add_node_list (node, NULL,
+							"font",
+							items);
+				break;
 			case AS_PROVIDED_KIND_FIRMWARE_RUNTIME:
 				for (j = 0; j < items->len; j++) {
 					xmlNode *n;
@@ -1660,7 +1694,6 @@ as_xml_serialize_provides (AsComponent *cpt, xmlNode *cnode)
 				break;
 
 			default:
-				/* TODO: Serialize fonts tag properly */
 				g_debug ("Couldn't serialize provided-item type '%s'", as_provided_kind_to_string (as_provided_get_kind (prov)));
 				break;
 		}
@@ -1745,6 +1778,36 @@ as_xmldata_serialize_suggests (AsXMLData *xdt, AsComponent *cpt, xmlNode *cptnod
 	}
 }
 
+/**
+ * as_xml_serialize_custom:
+ */
+static void
+as_xml_serialize_custom (AsComponent *cpt, xmlNode *cptnode)
+{
+	xmlNode *node;
+	GHashTable *custom;
+	GHashTableIter iter;
+	gpointer key, value;
+
+	custom = as_component_get_custom (cpt);
+	if (g_hash_table_size (custom) == 0)
+		return;
+
+	node = xmlNewChild (cptnode, NULL, (xmlChar*) "custom", NULL);
+	g_hash_table_iter_init (&iter, custom);
+	while (g_hash_table_iter_next (&iter, &key, &value)) {
+		xmlNode *snode;
+
+		snode = xmlNewTextChild (node,
+					  NULL,
+					  (xmlChar*) "value",
+					  (xmlChar*) value);
+		xmlNewProp (snode,
+			    (xmlChar*) "key",
+			    (xmlChar*) key);
+	}
+}
+
 /**
  * as_xmldata_component_to_node:
  * @cpt: a valid #AsComponent
@@ -1817,6 +1880,14 @@ as_xmldata_component_to_node (AsXMLData *xdt, AsComponent *cpt)
 				(GHFunc) as_xml_lang_hashtable_to_nodes_cb,
 				&helper);
 
+	/* order license and project group after name/summary */
+	if (priv->mode == AS_FORMAT_STYLE_METAINFO)
+		as_xml_add_text_node (cnode, "metadata_license", as_component_get_metadata_license (cpt));
+
+	as_xml_add_text_node (cnode, "project_license", as_component_get_project_license (cpt));
+	as_xml_add_text_node (cnode, "project_group", as_component_get_project_group (cpt));
+
+	/* continue with long description and developer name */
 	helper.nd = NULL;
 	helper.node_name = "developer_name";
 	g_hash_table_foreach (as_component_get_developer_name_table (cpt),
@@ -1829,8 +1900,7 @@ as_xmldata_component_to_node (AsXMLData *xdt, AsComponent *cpt)
 					(GHFunc) as_xml_desc_lang_hashtable_to_nodes_cb,
 					&helper);
 
-	as_xml_add_text_node (cnode, "project_license", as_component_get_project_license (cpt));
-	as_xml_add_text_node (cnode, "project_group", as_component_get_project_group (cpt));
+
 
 	as_xml_add_node_list_strv (cnode, NULL, "pkgname", as_component_get_pkgnames (cpt));
 
@@ -1947,6 +2017,9 @@ as_xmldata_component_to_node (AsXMLData *xdt, AsComponent *cpt)
 	/* suggests node */
 	as_xmldata_serialize_suggests (xdt, cpt, cnode);
 
+	/* custom node */
+	as_xml_serialize_custom (cpt, cnode);
+
 	return cnode;
 }
 
