@@ -253,7 +253,6 @@ as_yamldata_get_localized_node (AsYAMLData *ydt, GNode *node, gchar *locale_over
 {
 	GNode *n;
 	GNode *tnode = NULL;
-	const gchar *key;
 	const gchar *locale;
 	AsYAMLDataPrivate *priv = GET_PRIVATE (ydt);
 
@@ -263,7 +262,7 @@ as_yamldata_get_localized_node (AsYAMLData *ydt, GNode *node, gchar *locale_over
 		locale = locale_override;
 
 	for (n = node->children; n != NULL; n = n->next) {
-		key = as_yaml_node_get_key (n);
+		const gchar *key = as_yaml_node_get_key (n);
 
 		if ((tnode == NULL) && (g_strcmp0 (key, "C") == 0)) {
 			tnode = n;
@@ -540,7 +539,7 @@ as_yaml_process_provides (GNode *node, AsComponent *cpt)
 						continue;
 					if (g_strcmp0 (dkey, "type") == 0) {
 						kind = dvalue;
-					} else if ((g_strcmp0 (dkey, "guid") == 0) || (g_strcmp0 (dkey, "fname") == 0)) {
+					} else if ((g_strcmp0 (dkey, "guid") == 0) || (g_strcmp0 (dkey, "file") == 0)) {
 						fwdata = dvalue;
 					}
 				}
@@ -739,6 +738,8 @@ as_yamldata_process_releases (AsYAMLData *ydt, GNode *node, AsComponent *cpt)
 				}
 			} else if (g_strcmp0 (key, "version") == 0) {
 				as_release_set_version (rel, value);
+			} else if (g_strcmp0 (key, "urgency") == 0) {
+				as_release_set_urgency (rel, as_urgency_kind_from_string (value));
 			} else if (g_strcmp0 (key, "description") == 0) {
 				gchar *lvalue;
 				lvalue = as_yamldata_get_localized_value (ydt, node, NULL);
@@ -756,10 +757,10 @@ as_yamldata_process_releases (AsYAMLData *ydt, GNode *node, AsComponent *cpt)
 }
 
 /**
- * as_yamldata_process_languages:
+ * as_yaml_process_languages:
  */
 static void
-as_yamldata_process_languages (GNode *node, AsComponent *cpt)
+as_yaml_process_languages (GNode *node, AsComponent *cpt)
 {
 	GNode *sn;
 
@@ -794,10 +795,10 @@ as_yamldata_process_languages (GNode *node, AsComponent *cpt)
 }
 
 /**
- * as_yamldata_process_suggests:
+ * as_yaml_process_suggests:
  */
 static void
-as_yamldata_process_suggests (GNode *node, AsComponent *cpt)
+as_yaml_process_suggests (GNode *node, AsComponent *cpt)
 {
 	GNode *sn;
 
@@ -829,6 +830,25 @@ as_yamldata_process_suggests (GNode *node, AsComponent *cpt)
 	}
 }
 
+/**
+ * as_yaml_process_custom:
+ */
+static void
+as_yaml_process_custom (GNode *node, AsComponent *cpt)
+{
+	GNode *sn;
+
+	for (sn = node->children; sn != NULL; sn = sn->next) {
+		const gchar *key;
+		const gchar *value;
+
+		key = as_yaml_node_get_key (sn);
+		value = as_yaml_node_get_value (sn);
+
+		as_component_insert_custom_value (cpt, key, value);
+	}
+}
+
 /**
  * as_yamldata_process_component_node:
  */
@@ -925,11 +945,13 @@ as_yamldata_process_component_node (AsYAMLData *ydt, GNode *root)
 		} else if (g_strcmp0 (key, "Screenshots") == 0) {
 			as_yamldata_process_screenshots (ydt, node, cpt);
 		} else if (g_strcmp0 (key, "Languages") == 0) {
-			as_yamldata_process_languages (node, cpt);
+			as_yaml_process_languages (node, cpt);
 		} else if (g_strcmp0 (key, "Releases") == 0) {
 			as_yamldata_process_releases (ydt, node, cpt);
 		} else if (g_strcmp0 (key, "Suggests") == 0) {
-			as_yamldata_process_suggests (node, cpt);
+			as_yaml_process_suggests (node, cpt);
+		} else if (g_strcmp0 (key, "Custom") == 0) {
+			as_yaml_process_custom (node, cpt);
 		} else {
 			as_yaml_print_unknown ("root", key);
 		}
@@ -1408,7 +1430,6 @@ as_yaml_emit_provides (yaml_emitter_t *emitter, AsComponent *cpt)
 					as_yaml_emit_entry (emitter,
 							    "name",
 							    (const gchar*) g_ptr_array_index (items, j));
-					/* FIXME: Also emit "file" entry, but at time we don't seem to store this? */
 					as_yaml_mapping_end (emitter);
 				}
 				as_yaml_sequence_end (emitter);
@@ -1502,7 +1523,7 @@ as_yaml_emit_provides (yaml_emitter_t *emitter, AsComponent *cpt)
 				as_yaml_mapping_start (emitter);
 
 				as_yaml_emit_entry (emitter, "type", "flashed");
-				as_yaml_emit_entry (emitter, "fname", value);
+				as_yaml_emit_entry (emitter, "file", value);
 
 				as_yaml_mapping_end (emitter);
 			}
@@ -1861,7 +1882,7 @@ as_yaml_data_emit_suggests (AsYAMLData *ydt, yaml_emitter_t *emitter, AsComponen
 	if (suggestions->len == 0)
 		return;
 
-	as_yaml_emit_scalar (emitter, "Suggested");
+	as_yaml_emit_scalar (emitter, "Suggests");
 	as_yaml_sequence_start (emitter);
 
 	for (i = 0; i < suggestions->len; i++) {
@@ -1887,6 +1908,33 @@ as_yaml_data_emit_suggests (AsYAMLData *ydt, yaml_emitter_t *emitter, AsComponen
 	as_yaml_sequence_end (emitter);
 }
 
+/**
+ * as_yaml_data_emit_custom:
+ */
+static void
+as_yaml_data_emit_custom (AsYAMLData *ydt, yaml_emitter_t *emitter, AsComponent *cpt)
+{
+	GHashTable *custom;
+	GHashTableIter iter;
+	gpointer key, value;
+
+	custom = as_component_get_custom (cpt);
+	if (g_hash_table_size (custom) == 0)
+		return;
+
+	as_yaml_emit_scalar (emitter, "Custom");
+	as_yaml_mapping_start (emitter);
+
+	g_hash_table_iter_init (&iter, custom);
+	while (g_hash_table_iter_next (&iter, &key, &value)) {
+		as_yaml_emit_entry (emitter,
+				    (const gchar*) key,
+				    (const gchar*) value);
+	}
+
+	as_yaml_mapping_end (emitter);
+}
+
 /**
  * as_yaml_serialize_component:
  */
@@ -2042,6 +2090,9 @@ as_yaml_serialize_component (AsYAMLData *ydt, yaml_emitter_t *emitter, AsCompone
 	/* Suggests */
 	as_yaml_data_emit_suggests (ydt, emitter, cpt);
 
+	/* Custom fields */
+	as_yaml_data_emit_custom (ydt, emitter, cpt);
+
 	/* close main mapping */
 	as_yaml_mapping_end (emitter);
 
