@@ -20,6 +20,9 @@
 
 #include <glib.h>
 #include "appstream.h"
+#include "as-component-private.h"
+
+#include "as-test-utils.h"
 
 static gchar *datadir = NULL;
 
@@ -218,6 +221,16 @@ test_spdx (void)
 	g_strfreev (tok);
 	g_free (tmp);
 
+	/* "+" operator */
+	tok = as_spdx_license_tokenize ("CC-BY-SA-3.0+ AND Zlib");
+	tmp = g_strjoinv ("  ", tok);
+	g_assert_cmpstr (tmp, ==, "@CC-BY-SA-3.0  +  &  @Zlib");
+	g_free (tmp);
+	tmp = as_spdx_license_detokenize (tok);
+	g_assert_cmpstr (tmp, ==, "CC-BY-SA-3.0+ AND Zlib");
+	g_strfreev (tok);
+	g_free (tmp);
+
 	/* detokenisation literals */
 	tok = as_spdx_license_tokenize ("Public Domain");
 	tmp = as_spdx_license_detokenize (tok);
@@ -256,6 +269,8 @@ test_spdx (void)
 	g_assert (as_is_spdx_license_expression ("LicenseRef-proprietary"));
 	g_assert (as_is_spdx_license_expression ("CC0-1.0 and GFDL-1.3"));
 	g_assert (as_is_spdx_license_expression ("CC0-1.0 AND GFDL-1.3"));
+	g_assert (as_is_spdx_license_expression ("CC-BY-SA-3.0+"));
+	g_assert (as_is_spdx_license_expression ("CC-BY-SA-3.0+ AND Zlib"));
 	g_assert (as_is_spdx_license_expression ("NOASSERTION"));
 	g_assert (!as_is_spdx_license_expression ("CC0 dave"));
 	g_assert (!as_is_spdx_license_expression (""));
@@ -274,6 +289,89 @@ test_spdx (void)
 	g_assert (!as_license_is_metadata_license ("GPL-2.0 AND FSFAP"));
 }
 
+/**
+ * test_desktop_entry:
+ *
+ * Test reading a desktop-entry.
+ */
+static void
+test_desktop_entry ()
+{
+	g_autoptr(AsMetadata) metad = NULL;
+	g_autofree gchar *nautilus_de_fname = NULL;
+	g_autofree gchar *ksysguard_de_fname = NULL;
+	g_autofree gchar *expected_xml = NULL;
+	g_autoptr(GFile) file = NULL;
+	g_autoptr(GError) error = NULL;
+	AsComponent *cpt;
+	GPtrArray *cpts;
+	guint i;
+	gchar *tmp;
+
+	nautilus_de_fname = g_build_filename (datadir, "org.gnome.Nautilus.desktop", NULL);
+	ksysguard_de_fname = g_build_filename (datadir, "org.kde.ksysguard.desktop", NULL);
+
+	/* Nautilus */
+	file = g_file_new_for_path (nautilus_de_fname);
+
+	metad = as_metadata_new ();
+	as_metadata_parse_file (metad, file, AS_FORMAT_KIND_UNKNOWN, &error);
+	g_assert_no_error (error);
+	cpt = as_metadata_get_component (metad);
+
+	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.gnome.Nautilus");
+	g_assert_cmpint (as_component_get_kind (cpt), ==, AS_COMPONENT_KIND_DESKTOP_APP);
+
+	as_component_set_active_locale (cpt, "C");
+	g_assert_cmpstr (as_component_get_name (cpt), ==, "Files");
+
+	as_component_set_active_locale (cpt, "lt");
+	g_assert_cmpstr (as_component_get_name (cpt), ==, "Failai");
+
+	/* clear */
+	g_object_unref (file);
+	file = NULL;
+	as_metadata_clear_components (metad);
+
+	/* KSysGuard */
+	file = g_file_new_for_path (ksysguard_de_fname);
+	as_metadata_parse_file (metad, file, AS_FORMAT_KIND_UNKNOWN, &error);
+	g_assert_no_error (error);
+	cpt = as_metadata_get_component (metad);
+
+	g_assert_cmpstr (as_component_get_id (cpt), ==, "org.kde.ksysguard");
+	g_assert_cmpint (as_component_get_kind (cpt), ==, AS_COMPONENT_KIND_DESKTOP_APP);
+
+	as_component_set_active_locale (cpt, "C");
+	g_assert_cmpstr (as_component_get_name (cpt), ==, "KSysGuard");
+
+	/* validate everything */
+
+	/* add nautilus again */
+	g_object_unref (file);
+	file = g_file_new_for_path (nautilus_de_fname);
+	as_metadata_parse_file (metad, file, AS_FORMAT_KIND_DESKTOP_ENTRY, &error);
+	g_assert_no_error (error);
+
+	/* adjust the priority */
+	cpts = as_metadata_get_components (metad);
+	for (i = 0; i < cpts->len; i++) {
+		cpt = AS_COMPONENT (g_ptr_array_index (cpts, i));
+		as_component_set_priority (cpt, -1);
+	}
+
+	/* get expected XML */
+	tmp = g_build_filename (datadir, "desktop-converted.xml", NULL);
+	g_file_get_contents (tmp, &expected_xml, NULL, &error);
+	g_assert_no_error (error);
+	g_free (tmp);
+
+	tmp = as_metadata_components_to_collection (metad, AS_FORMAT_KIND_XML, &error);
+	g_assert_no_error (error);
+	g_assert (as_test_compare_lines (tmp, expected_xml));
+	g_free (tmp);
+}
+
 int
 main (int argc, char **argv)
 {
@@ -299,6 +397,7 @@ main (int argc, char **argv)
 	g_test_add_func ("/AppStream/Component", test_component);
 	g_test_add_func ("/AppStream/SPDX", test_spdx);
 	g_test_add_func ("/AppStream/TranslationFallback", test_translation_fallback);
+	g_test_add_func ("/AppStream/DesktopEntry", test_desktop_entry);
 
 	ret = g_test_run ();
 	g_free (datadir);
