@@ -88,6 +88,7 @@ test_cache ()
 	as_component_set_id (cpt2, "org.example.NewFooBar");
 	as_component_set_name (cpt2, "Second FooBar App", NULL);
 	as_component_set_summary (cpt2, "Another unit-test dummy entry", NULL);
+	as_component_insert_custom_value (cpt2, "mykey", "stuff");
 
 	/* add data to the pool */
 	dpool = as_pool_new ();
@@ -123,6 +124,7 @@ test_cache ()
 	g_assert_cmpint (as_component_get_kind (cpt2), ==, AS_COMPONENT_KIND_DESKTOP_APP);
 	g_assert_cmpstr (as_component_get_name (cpt2), ==, "Second FooBar App");
 	g_assert_cmpstr (as_component_get_summary (cpt2), ==, "Another unit-test dummy entry");
+	g_assert_cmpstr (as_component_get_custom_value (cpt2, "mykey"), ==, "stuff");
 }
 
 /**
@@ -134,6 +136,7 @@ static AsPool*
 test_get_sampledata_pool (gboolean use_caches)
 {
 	AsPool *pool;
+	AsPoolFlags flags;
 	g_autofree gchar *mdata_dir = NULL;
 
 	/* create AsPool and load sample metadata */
@@ -144,6 +147,10 @@ test_get_sampledata_pool (gboolean use_caches)
 	as_pool_add_metadata_location (pool, mdata_dir);
 	as_pool_set_locale (pool, "C");
 
+	flags = as_pool_get_flags (pool);
+	as_flags_remove (flags, AS_POOL_FLAG_READ_DESKTOP_FILES);
+	as_pool_set_flags (pool, flags);
+
 	if (!use_caches)
 		as_pool_set_cache_flags (pool, AS_CACHE_FLAG_NONE);
 
